@@ -13,7 +13,7 @@
 #include <KLocalizedString>
 #include <KAuthorized>
 
-#include <qglobal.h>
+#include <QtGlobal>
 #include <qplatformdefs.h>
 
 #include <stdlib.h>
@@ -156,7 +156,7 @@ QString ShellProcess::errorMessage() const
         case INACTIVE:
         case RUNNING:
         default:
-            return QString();
+            return {};
     }
 }
 
